SVMModel class
Support Vector Machine Model (Linear, OvR, Hinge Loss + L2)
Constructors
Properties
-
biases
→ Map<
String, double> -
Get learned biases
no setter
-
classes
→ List<
String> -
Get list of trained class labels
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- learningRate → double
-
final
- maxIterations → int
-
final
- regularizationC → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tolerance → double
-
final
-
weights
→ Map<
String, Float64List> -
Get learned weights
no setter
Methods
-
decisionFunction(
Float64List x) → Map< String, double> - Compute raw decision scores for each class
-
fit(
List< Float64List> X, List<String> y) → void - Train the model using One-vs-Rest strategy
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
predict(
Float64List x) → String - Predict the class label for a single input vector
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited